==> mxnet-engine-0.2.0-sources.jar: ai/djl/mxnet/jna/ConfigSpace.java <==
package ai.djl.mxnet.jna;

import com.sun.jna.Pointer;
import com.sun.jna.Structure;
import com.sun.jna.ptr.PointerByReference;
import java.util.Arrays;
import java.util.List;

public class ConfigSpace extends Structure {

    private int entity_map_size;
    private PointerByReference entity_map_key;
    private OtherOptionEntity.ByReference entity_map_val;
    private int space_map_size;
    private PointerByReference space_map_key;
    private OtherOptionSpace.ByReference space_map_val;

    public ConfigSpace() {
    }

    public ConfigSpace(Pointer peer) {
        super(peer);
    }

    @Override
    protected List<String> getFieldOrder() {
        return Arrays.asList("entity_map_size", "entity_map_key", "entity_map_val", "space_map_size", "space_map_key", "space_map_val");
    }

    public void setEntityMapSize(int entity_map_size) {
        this.entity_map_size = entity_map_size;
    }

    public int getEntityMapSize() {
        return entity_map_size;
    }

    public void setEntityMapKey(PointerByReference entity_map_key) {
        this.entity_map_key = entity_map_key;
    }

    public PointerByReference getEntityMapKey() {
        return entity_map_key;
    }

    public void setEntityMapVal(OtherOptionEntity.ByReference entity_map_val) {
        this.entity_map_val = entity_map_val;
    }

    public OtherOptionEntity.ByReference getEntityMapVal() {
        return entity_map_val;
    }

    public void setSpaceMapSize(int space_map_size) {
        this.space_map_size = space_map_size;
    }

    public int getSpaceMapSize() {
        return space_map_size;
    }

    public void setSpaceMapKey(PointerByReference space_map_key) {
        this.space_map_key = space_map_key;
    }

    public PointerByReference getSpaceMapKey() {
        return space_map_key;
    }

    public void setSpaceMapVal(OtherOptionSpace.ByReference space_map_val) {
        this.space_map_val = space_map_val;
    }

    public OtherOptionSpace.ByReference getSpaceMapVal() {
        return space_map_val;
    }

    public static final class ByReference extends ConfigSpace implements Structure.ByReference {}

    public static final class ByValue extends ConfigSpace implements Structure.ByValue {}
}

==> mxnet-engine-0.6.0-sources.jar: ai/djl/mxnet/jna/ConfigSpace.java <==
package ai.djl.mxnet.jna;

import com.sun.jna.Pointer;
import com.sun.jna.Structure;
import com.sun.jna.ptr.PointerByReference;
import java.util.Arrays;
import java.util.List;

public class ConfigSpace extends Structure {

    public int entity_map_size;
    public PointerByReference entity_map_key;
    public OtherOptionEntity.ByReference entity_map_val;
    public int space_map_size;
    public PointerByReference space_map_key;
    public OtherOptionSpace.ByReference space_map_val;

    public ConfigSpace() {
    }

    public ConfigSpace(Pointer peer) {
        super(peer);
    }

    @Override
    protected List<String> getFieldOrder() {
        return Arrays.asList("entity_map_size", "entity_map_key", "entity_map_val", "space_map_size", "space_map_key", "space_map_val");
    }

    public void setEntityMapSize(int entity_map_size) {
        this.entity_map_size = entity_map_size;
    }

    public int getEntityMapSize() {
        return entity_map_size;
    }

    public void setEntityMapKey(PointerByReference entity_map_key) {
        this.entity_map_key = entity_map_key;
    }

    public PointerByReference getEntityMapKey() {
        return entity_map_key;
    }

    public void setEntityMapVal(OtherOptionEntity.ByReference entity_map_val) {
        this.entity_map_val = entity_map_val;
    }

    public OtherOptionEntity.ByReference getEntityMapVal() {
        return entity_map_val;
    }

    public void setSpaceMapSize(int space_map_size) {
        this.space_map_size = space_map_size;
    }

    public int getSpaceMapSize() {
        return space_map_size;
    }

    public void setSpaceMapKey(PointerByReference space_map_key) {
        this.space_map_key = space_map_key;
    }

    public PointerByReference getSpaceMapKey() {
        return space_map_key;
    }

    public void setSpaceMapVal(OtherOptionSpace.ByReference space_map_val) {
        this.space_map_val = space_map_val;
    }

    public OtherOptionSpace.ByReference getSpaceMapVal() {
        return space_map_val;
    }

    public static final class ByReference extends ConfigSpace implements Structure.ByReference {}

    public static final class ByValue extends ConfigSpace implements Structure.ByValue {}
}
